==> react-windows-ui-1.0.4.tgz: package/README.md <==
<h2 align="center"> 
  <img src="https://github.com/virtualvivek/react-windows-ui/blob/main/markdown/md_img_header.png" width="402" /> 
</h2>
<h1 align="center">react-windows-ui</h1>

<p align="center">Build full featured Windows fluent UI apps using reactjs.</p>

<p align="center">
	
  <a href="https://github.com/virtualvivek/react-windows-ui/blob/main/LICENSE">
    <img src="https://img.shields.io/badge/License-MIT-darklime.svg?style=flat-square&color=blue"
      alt="License: MIT" />
  </a>
  
  <a href="https://virtualvivek.github.io/react-windows-ui/">
    <img src="https://img.shields.io/github/package-json/v/virtualvivek/react-windows-ui?color=%2331b57e&style=flat-square"
      alt="Version" />
  </a>
  
  <a href="https://virtualvivek.github.io/react-windows-ui/">
    <img src="https://img.shields.io/badge/⚡ Live Demo-here-green.svg?color=%236a31b5&style=flat-square"
      alt="Live Demo" />
  </a>
   
</p>

<h2 align="center">
  <img src="https://github.com/virtualvivek/react-windows-ui/blob/main/markdown/md_img_promo.png" width="652" /> 
</h2>

## Demo ⚡
https://virtualvivek.github.io/react-windows-ui/

## Installation
```js
npm install react-windows-ui --save
```

## Getting Started

```js
import { NavBar,NavPageContainer, ..} from 'react-windows-ui'
```

```js
// Be sure to include styles at some point, probably during your bootstraping
import 'react-windows-ui/config/app-config.css'
import 'react-windows-ui/dist/react-windows-ui.min.css'
import 'react-windows-ui/icons/fonts/fonts.min.css'
```
### app-config
You can import default `app-config` using this file <a href="https://github.com/virtualvivek/react-windows-ui/blob/main/src/lib/config/app-config.css">app-config.css</a><br>
OR <br>
Create your own like this

```css
:root {
    --AppColor: #6632a8;
 /*   Change of your choice */
}
body {
    font-weight: 400;
    font-size: 1em;
    font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Helvetica Neue", sans-serif;
    text-rendering: optimizeLegibility;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
}
```

## Find this library useful? :heart:
Support it by joining [stargazers](https://github.com/virtualvivek/react-windows-ui/stargazers) for this repository. :star:


## License

`react-windows-ui` is licensed under `MIT license`. View [license](https://github.com/virtualvivek/react-windows-ui/blob/master/LICENSE).<br>
Copyright (c) 2021 ` Vivek Verma `

==> react-windows-ui-1.0.5.tgz: package/README.md <==
<h2 align="center"> 
  <img src="https://github.com/virtualvivek/react-windows-ui/blob/main/markdown/md_img_header.png" width="402" /> 
</h2>
<h1 align="center">react-windows-ui</h1>

<p align="center">Build full featured Windows fluent UI apps using ReactJS.</p>

<p align="center">
	
  <a href="https://virtualvivek.github.io/react-windows-ui/">
    <img src="https://img.shields.io/circleci/build/github/virtualvivek/react-windows-ui?style=flat-square&logo=circleci&token=346e79ab71a8d9c3bad22bacbebc7d7c50dae520"
      alt="Build" />
  </a>
	
  <a href="https://github.com/virtualvivek/react-windows-ui/blob/main/LICENSE">
    <img src="https://img.shields.io/badge/License-MIT-darklime.svg?style=flat-square&color=blue"
      alt="License: MIT" />
  </a>
  
  <a href="https://virtualvivek.github.io/react-windows-ui/">
    <img src="https://img.shields.io/github/package-json/v/virtualvivek/react-windows-ui?color=%2331b57e&style=flat-square"
      alt="Version" />
  </a>
  
  <a href="https://virtualvivek.github.io/react-windows-ui/">
    <img src="https://img.shields.io/badge/⚡ Live Demo-here-green.svg?color=%236a31b5&style=flat-square"
      alt="Live Demo" />
  </a>
   
</p>

<h2 align="center">
  <img src="https://github.com/virtualvivek/react-windows-ui/blob/main/markdown/md_img_promo.png" width="652" /> 
</h2>

## Demo ⚡
https://virtualvivek.github.io/react-windows-ui/

## Installation
```js
npm install react-windows-ui
```

## Getting Started

```js
import { NavBar,NavPageContainer, ..} from 'react-windows-ui'
```

```js
// Be sure to include styles at some point, probably during your bootstraping
import 'react-windows-ui/config/app-config.css'
import 'react-windows-ui/dist/react-windows-ui.min.css'
import 'react-windows-ui/icons/fonts/fonts.min.css'
```
### app-config

‣ `app-config` file contains the primary `AppColor`, `Fontfamily` used by the app <br>
‣ You can import default `app-config` using this file <a href="https://github.com/virtualvivek/react-windows-ui/blob/main/src/lib/config/app-config.css">app-config.css</a><br>
OR <br>
Create your own like this

```css
:root {
    --AppColor: #6632a8;
 /*   Change of your choice */
}
body {
    font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Helvetica Neue", sans-serif;
    text-rendering: optimizeLegibility;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
}
```

## ‣ Example Code
https://github.com/virtualvivek/react-windows-ui/tree/main/src/demo

## ‣ Library Source Code
https://github.com/virtualvivek/react-windows-ui/tree/main/src/lib


## Find this library useful? :heart:
Support it by joining [stargazers](https://github.com/virtualvivek/react-windows-ui/stargazers) for this repository. :star:


## License

`react-windows-ui` is licensed under `MIT license`. View [license](https://github.com/virtualvivek/react-windows-ui/blob/main/LICENSE).<br>
Copyright (c) 2021 ` Vivek Verma `
